# -*- coding: utf-8 -*-

import urllib2
import urllib
import sys

import words
import tips
import stringfuncs as sf

import os

from datetime import datetime

if len(sys.argv) < 2:
    sys.exit()

# Get data
word = sys.argv[1].decode('utf-8').encode('cp1251')
url = 'http://starling.rinet.ru/cgi-bin/morph.cgi?flags=endnnnnn&root=config&word=' + urllib.quote(word)
p = urllib2.urlopen(url)

# Stress
html = p.read().decode('cp1251')

# Find russian words
ruswordlist = []
start = 0
search = 'Source form:'
while True:
    r = sf.findbetween(html, search, '<p>', '', start)
    if r[2] == 0:
        break
    start = r[0]+1

    newword = words.RusWord(r[1])
    ruswordlist.append(newword)

    r = sf.findbetween(html, 'Dictionary information:', '<p>', search, start)
    if r[0] != 0:
        newword.dictinfo = r[1]

    r = sf.findbetween(html, 'Translation:', '<p>', search, start)
    if r[0] != 0:
        newword.translations = r[1]

    r = sf.findbetween(html, 'Morphological characteristics:', '<p>', search, start)
    if r[0] != 0:
        newword.characteristics = r[1]

# Find morphology
i = 1
for word in ruswordlist:
    if len(ruswordlist) == 1:
        r = sf.findbetween(html, '<hr>', '<hr>', '', 0)
    else:
        r = sf.findbetween(html, str(i) + ' variant:\n<br>', '<hr>', '', 0)
    if r[0] != 0:
        word.morphology = r[1].strip()
    i = i+1

# Find english words
engwordlist = []
start = 0
search = '<FONT COLOR="#009900"><FONT SIZE=+2>'
while True:
    r = sf.findbetween(html, search, '</FONT>', '', start)
    if r[2] == 0:
        break
    start = r[0]+1

    newword = words.EngWord(r[1])
    engwordlist.append(newword)

    r = html.find('.', start)
    if r != -1 and r < len(html)-2:
        if html[r+2] == 'n':
            newword.typ = 'Noun'
        elif html[r+2] == 'v':
            newword.typ = 'Verb'

    q = start
    while True:
        r = sf.findbetween(html, ')', '<p>', search, q)
        if r[2] == 0:
            break
        q = r[0] + 1
        if html[r[0]-1].isdigit():
            s = r[1].split(';')
            e = words.Entry()
            e.main = s[0].strip()
            for i in range(1,len(s)):
                e.sub.append(s[i].strip())
            newword.entries.append(e)

# Clean up
for word in ruswordlist:
    word.morphology = sf.removeall(word.morphology, '<br>')
    word.morphology = word.morphology.replace('<h2>', '<p class="h2">')
    word.morphology = word.morphology.replace('</h2>', '</p>')
    word.morphology = word.morphology.replace('<h3>', '<p class="h3">')
    word.morphology = word.morphology.replace('</h3>', '</p>')
    word.morphology = sf.enclose(word.morphology, '<b>', '\n', '<p class="ininfo">', '</p>')
    word.morphology = word.morphology.replace('//', '/')
    word.morphology = sf.fixstress(word.morphology)

    word.dictinfo = sf.forcespaceafter(word.dictinfo, ',', True)
    word.dictinfo = ' ' + word.dictinfo + ' '
    word.dictinfo = sf.inserttips(word.dictinfo, tips.tips)
    word.dictinfo = word.dictinfo[1:len(word.dictinfo)]
    word.dictinfo = sf.fixstress(word.dictinfo)

    word.translations = sf.forcespaceafter(word.translations, ';', True)
    word.translations = sf.removebetweeninclusive(word.translations, '||[', '"')
    word.translations = word.translations.replace('morph.cgi?flags=endnnnnn&', 'index.php?')
    word.translations = sf.fixstress(word.translations)

    word.characteristics = sf.forcespaceafter(word.characteristics, ',', True)
    word.characteristics = ' ' + word.characteristics + ' '
    word.characteristics = sf.inserttips(word.characteristics, tips.tips)
    word.characteristics = word.characteristics[1:len(word.characteristics)]
    word.characteristics = sf.fixstress(word.characteristics)

    word.word = sf.fixstress(word.word)

for word in engwordlist:
    for e in word.entries:
        e.main = sf.fixstress(e.main)
        for i in range(0,len(e.sub)):
            e.sub[i] = sf.fixstress(e.sub[i])
            e.sub[i] = e.sub[i].replace('¬'.decode('utf-8'), word.word)
            found = False
            for j in range(0,len(e.sub[i])):
                if sf.iscyrillic(e.sub[i][j]):
                    found = True
                    break
            if found:
                e.sub[i] = e.sub[i][0:j].strip() + ' &rarr; ' + e.sub[i][j:len(e.sub[i])]

#print '........................................'

# Output
if True:
    for k, v in tips.tips.iteritems():
        print '<div id="' + k + '" class="tip">' + v + '</div>'

    if len(ruswordlist) == 0 and len(engwordlist) == 0:
        print '<p align="center">No results found for "' + sys.argv[1] + '".</p>'
    else:
        print '<div class="tabber">'

        for word in ruswordlist:
            print '<div class="tabbertab">'
            print '<h2>' + word.word.encode('utf-8') + '</h2>'
            print '<p><u>' + word.word.encode('utf-8') + '</u></p>'
            if word.dictinfo != '':
                print '<p class="info"><b>Dictionary information:</b> ' + word.dictinfo.encode('utf-8') + '</p>'
            if word.translations != '':
                print '<p class="info"><b>Translations:</b> ' + word.translations.encode('utf-8') + '</p>'
            if word.characteristics != '':
                print '<p class="info"><b>Morphological characteristics of ' + sys.argv[1] + ':</b> ' + word.characteristics.encode('utf-8') + '</p>'
            if word.morphology != '':
                print '<div style="padding-left: 15px; padding-bottom: 15px;">'
                print word.morphology.encode('utf-8')
                print '</div>'
            print '</div>'

        for word in engwordlist:
            print '<div class="tabbertab">'
            print '<h2>' + word.word.encode('utf-8') + '</h2>'
            print '<p><u>' + word.word.encode('utf-8') + '</u></p>'
            if word.typ != '':
                print '<p class="info"><b>Class:</b> ' + word.typ + '</p>'
            if len(word.entries) > 0:
                print '<ol>'
                for entry in word.entries:
                    print '<li>' + entry.main.encode('utf-8') + '</li>'
                    if len(entry.sub) > 0:
                        print '<ol>'
                        for s in entry.sub:
                            print '<li>' + s.encode('utf-8') + '</li>'
                        print '</ol>'
                print '</ol>'
            print '</div>'

        print '</div>'
